about summary refs log tree commit diff
path: root/hurd/hurd/sigpreempt.h
diff options
context:
space:
mode:
Diffstat (limited to 'hurd/hurd/sigpreempt.h')
-rw-r--r--hurd/hurd/sigpreempt.h64
1 files changed, 32 insertions, 32 deletions
diff --git a/hurd/hurd/sigpreempt.h b/hurd/hurd/sigpreempt.h
index 1bd6589e32..44572a6d27 100644
--- a/hurd/hurd/sigpreempt.h
+++ b/hurd/hurd/sigpreempt.h
@@ -1,21 +1,21 @@
 /* Preemption of Hurd signals before POSIX.1 semantics take over.
-Copyright (C) 1996 Free Software Foundation, Inc.
-This file is part of the GNU C Library.
+   Copyright (C) 1996 Free Software Foundation, Inc.
+   This file is part of the GNU C Library.
 
-The GNU C Library is free software; you can redistribute it and/or
-modify it under the terms of the GNU Library General Public License as
-published by the Free Software Foundation; either version 2 of the
-License, or (at your option) any later version.
+   The GNU C Library is free software; you can redistribute it and/or
+   modify it under the terms of the GNU Library General Public License as
+   published by the Free Software Foundation; either version 2 of the
+   License, or (at your option) any later version.
 
-The GNU C Library is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-Library General Public License for more details.
+   The GNU C Library is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+   Library General Public License for more details.
 
-You should have received a copy of the GNU Library General Public
-License along with the GNU C Library; see the file COPYING.LIB.  If
-not, write to the Free Software Foundation, Inc., 675 Mass Ave,
-Cambridge, MA 02139, USA.  */
+   You should have received a copy of the GNU Library General Public
+   License along with the GNU C Library; see the file COPYING.LIB.  If not,
+   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+   Boston, MA 02111-1307, USA.  */
 
 #ifndef	_HURD_SIGPREEMPT_H
 
@@ -25,7 +25,7 @@ Cambridge, MA 02139, USA.  */
 struct hurd_sigstate;		/* <hurd/signal.h> */
 struct hurd_signal_detail;	/* <hurd/signal.h> */
 
-struct hurd_signal_preempter
+struct hurd_signal_preemptor
   {
     /* These members select which signals this structure will apply to.
        The rest of the structure is only consulted if these match.  */
@@ -34,35 +34,35 @@ struct hurd_signal_preempter
 
     /* This function will be called (with SS->lock held) to decide what to
        do with the signal described.  It may modify the codes of the signal
-       passed.  If the return value is SIG_ERR, the next matching preempter
+       passed.  If the return value is SIG_ERR, the next matching preemptor
        is tried, or the normal handling is done for the signal (which may
-       have been changed by the preempter function).  Otherwise, the signal
+       have been changed by the preemptor function).  Otherwise, the signal
        is processed as if the return value were its handler setting.  */
-    sighandler_t (*preempter) (struct hurd_signal_preempter *preempter,
+    sighandler_t (*preemptor) (struct hurd_signal_preemptor *preemptor,
 			       struct hurd_sigstate *ss,
 			       int *signo, struct hurd_signal_detail *detail);
     /* If PREEMPTER is null, act as if it returned HANDLER.  */
     sighandler_t handler;
 
-    struct hurd_signal_preempter *next;	/* List structure.  */
+    struct hurd_signal_preemptor *next;	/* List structure.  */
   };
 
-#define HURD_PREEMPT_SIGNAL_P(preempter, signo, sigcode) \
-  (((preempter)->signals & sigmask (signo)) && \
-   (sigcode) >= (preempter)->first && (sigcode) <= (preempter)->last)
+#define HURD_PREEMPT_SIGNAL_P(preemptor, signo, sigcode) \
+  (((preemptor)->signals & sigmask (signo)) && \
+   (sigcode) >= (preemptor)->first && (sigcode) <= (preemptor)->last)
 
 
-/* Signal preempters applying to all threads; locked by _hurd_siglock.  */
-extern struct hurd_signal_preempter *_hurdsig_preempters;
+/* Signal preemptors applying to all threads; locked by _hurd_siglock.  */
+extern struct hurd_signal_preemptor *_hurdsig_preemptors;
 extern sigset_t _hurdsig_preempted_set;
 
 
-/* The caller must initialize all members of *PREEMPTER except `next'.
-   The preempter is registered on the global list.  */
-void hurd_preempt_signals (struct hurd_signal_preempter *preempter);
+/* The caller must initialize all members of *PREEMPTOR except `next'.
+   The preemptor is registered on the global list.  */
+void hurd_preempt_signals (struct hurd_signal_preemptor *preemptor);
 
-/* Remove a preempter registered with hurd_preempt_signals.  */
-void hurd_unpreempt_signals (struct hurd_signal_preempter *preempter);
+/* Remove a preemptor registered with hurd_preempt_signals.  */
+void hurd_unpreempt_signals (struct hurd_signal_preemptor *preemptor);
 
 
 /* Call *OPERATE and return its value.  If a signal in SIGSET with a sigcode
@@ -72,13 +72,13 @@ void hurd_unpreempt_signals (struct hurd_signal_preempter *preempter);
    hurd_catch_signal returns the sc_error value from the signal (or
    EGRATUITOUS if that is zero).
 
-   The preempter structure is passed to *OPERATE, which may modify its
+   The preemptor structure is passed to *OPERATE, which may modify its
    sigcode range or functions at any time during which it is guaranteed no
    signal in SIGSET will arrive.  */
 
 error_t hurd_catch_signal (sigset_t sigset,
 			   unsigned long int first, unsigned long int last,
-			   error_t (*operate) (struct hurd_signal_preempter *),
+			   error_t (*operate) (struct hurd_signal_preemptor *),
 			   sighandler_t handler);
@@ -34,35 +34,35 @@ struct hurd_signal_preempter
 			       struct hurd_sigstate *ss,
 			       int *signo, struct hurd_signal_detail *detail);
-    /* If PREEMPTER is null, act as if it returned HANDLER.  */
+    /* If PREEMPTOR is null, act as if it returned HANDLER.  */
     sighandler_t handler;
 